join_line_raw

Function join_line_raw 

pub fn join_line_raw<H: Host>(ed: &mut Editor<View, H>) -> bool
gJ — join the next line onto the current one without inserting a separating space or stripping leading whitespace. Returns false when the cursor is on the last line. See join_line.