toggle_case_at_cursor

Function toggle_case_at_cursor 

pub fn toggle_case_at_cursor<H: Host>(ed: &mut Editor<View, H>) -> bool
Returns false when there is no char under the cursor to toggle (end of line / empty line) so counted loops can stop instead of spinning through a saturated count prefix.