visual_join

Function visual_join 

pub fn visual_join<H: Host>(ed: &mut Editor<View, H>, with_space: bool)
Visual-mode J (with_space = true) / gJ (with_space = false) — join every line spanned by the selection into one. A single-line selection joins the current line with the one below (matching normal-mode J).