vim_editor

Function vim_editor 

pub fn vim_editor<H: Host>(
    buffer: Buffer,
    host: H,
    options: Options,
) -> Editor<Buffer, H>
Build an Editor with the vim discipline already installed.

The vim-flavoured counterpart of Editor::new, which yields an editor with no discipline at all.